@@ -347,10 +347,10 @@
   #define SIZEOF_SIZE_T  SIZEOF_LONG
 #else
 /* No indentation, to fetch the lines from verification scripts */
-#define SIZEOF_LONG   8
-#define SIZEOF_VOIDP  8
-#define SIZEOF_CHARP  8
-#define SIZEOF_SIZE_T 8
+#define SIZEOF_LONG   4
+#define SIZEOF_VOIDP  4
+#define SIZEOF_CHARP  4
+#define SIZEOF_SIZE_T 4
 #endif
 
 #define SIZEOF_CHAR 1
@@ -372,7 +372,7 @@
 /* #undef HAVE_UCHAR */
 #define SIZEOF_UINT 4
 #define HAVE_UINT 1
-#define SIZEOF_ULONG 8
+#define SIZEOF_ULONG 4
 #define HAVE_ULONG 1
 /* #undef SIZEOF_INT8 */
 /* #undef HAVE_INT8 */
@@ -473,7 +473,7 @@
 
 /* #undef MY_ATOMIC_MODE_DUMMY */
 /* #undef MY_ATOMIC_MODE_RWLOCKS */
-#define HAVE_GCC_ATOMIC_BUILTINS 1
+/* #undef HAVE_GCC_ATOMIC_BUILTINS */
 /* #undef HAVE_GCC_C11_ATOMICS */
 /* #undef HAVE_SOLARIS_ATOMIC */
 /* #undef HAVE_DECL_SHM_HUGETLB */
@@ -491,8 +491,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "OpenBSD"
-#define MACHINE_TYPE "sparc64"
-#define DEFAULT_MACHINE "sparc64"
+#define MACHINE_TYPE "powerpc"
+#define DEFAULT_MACHINE "powerpc"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -637,16 +637,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 0
-#define MYSQL_VERSION_PATCH 34
+#define MYSQL_VERSION_PATCH 36
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.0.34"
+#define PACKAGE_STRING "MySQL Server 10.0.36"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.0.34"
-#define VERSION "10.0.34"
+#define PACKAGE_VERSION "10.0.36"
+#define VERSION "10.0.36"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
