@@ -47,7 +47,7 @@
 #define HAVE_LIMITS_H 1
 /* #undef HAVE_LINUX_UNISTD_H */
 #define HAVE_LOCALE_H 1
-#define HAVE_MALLOC_H 1
+/* #undef HAVE_MALLOC_H */
 #define HAVE_MEMORY_H 1
 #define HAVE_NETINET_IN_H 1
 #define HAVE_PATHS_H 1
@@ -102,7 +102,7 @@
 #define HAVE_TIME_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_UTIME_H 1
-#define HAVE_VARARGS_H 1
+/* #undef HAVE_VARARGS_H */
 /* #undef HAVE_VIS_H */
 /* #undef HAVE_SYS_UTIME_H */
 #define HAVE_SYS_WAIT_H 1
@@ -216,7 +216,7 @@
 /* #undef HAVE_PORT_CREATE */
 /* #undef HAVE_POSIX_FALLOCATE */
 #define HAVE_PREAD 1
-/* #undef HAVE_PAUSE_INSTRUCTION */
+#define HAVE_PAUSE_INSTRUCTION 1
 /* #undef HAVE_FAKE_PAUSE_INSTRUCTION */
 /* #undef HAVE_RDTSCLL */
 /* #undef HAVE_READ_REAL_TIME */
@@ -347,10 +347,10 @@
   #define SIZEOF_SIZE_T  SIZEOF_LONG
 #else
 /* No indentation, to fetch the lines from verification scripts */
-#define SIZEOF_LONG   8
-#define SIZEOF_VOIDP  8
-#define SIZEOF_CHARP  8
-#define SIZEOF_SIZE_T 8
+#define SIZEOF_LONG   4
+#define SIZEOF_VOIDP  4
+#define SIZEOF_CHARP  4
+#define SIZEOF_SIZE_T 4
 #endif
 
 #define SIZEOF_CHAR 1
@@ -372,7 +372,7 @@
 /* #undef HAVE_UCHAR */
 #define SIZEOF_UINT 4
 #define HAVE_UINT 1
-#define SIZEOF_ULONG 8
+#define SIZEOF_ULONG 4
 #define HAVE_ULONG 1
 /* #undef SIZEOF_INT8 */
 /* #undef HAVE_INT8 */
@@ -474,7 +474,7 @@
 /* #undef MY_ATOMIC_MODE_DUMMY */
 /* #undef MY_ATOMIC_MODE_RWLOCKS */
 #define HAVE_GCC_ATOMIC_BUILTINS 1
-/* #undef HAVE_GCC_C11_ATOMICS */
+#define HAVE_GCC_C11_ATOMICS 1
 /* #undef HAVE_SOLARIS_ATOMIC */
 /* #undef HAVE_DECL_SHM_HUGETLB */
 /* #undef HAVE_LARGE_PAGES */
@@ -491,8 +491,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "OpenBSD"
-#define MACHINE_TYPE "mips64el"
-#define DEFAULT_MACHINE "mips64el"
+#define MACHINE_TYPE "i386"
+#define DEFAULT_MACHINE "i386"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -637,16 +637,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 0
-#define MYSQL_VERSION_PATCH 34
+#define MYSQL_VERSION_PATCH 36
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.0.34"
+#define PACKAGE_STRING "MySQL Server 10.0.36"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.0.34"
-#define VERSION "10.0.34"
+#define PACKAGE_VERSION "10.0.36"
+#define VERSION "10.0.36"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
